@@ -1,5 +1,6 @@
-package Params::Validate;
-$Params::Validate::VERSION = '1.13';
+package # hide from PAUSE
+    Params::Validate;
+
 BEGIN { $ENV{PARAMS_VALIDATE_IMPLEMENTATION} = 'XS' }
 use Params::Validate;
 
